=====================
How to cite **dupin**
=====================

Please acknowledge the use of this software within the body of your publication for example by copying or adapting the following formulation:

*Event detection for this publication used the dupin library[1].*

The following is a BibTex citation for the current pre-print.
Before submitting please check to see if this has been updated with the submitted journal paper::

    @misc{butler2023change,
      title={Change Point Detection of Events in Molecular Simulations using dupin},
      author={Brandon L. Butler and Domagoj Fijan and Sharon C. Glotzer},
      year={2023},
      eprint={2312.15090},
      archivePrefix={arXiv},
      primaryClass={physics.comp-ph}
    }
